@@ -24,8 +24,8 @@
  * ԥѥѹ
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.7 $
- * $Date: 2012/09/19 00:02:31 $
+ * $Revision: 1.8 $
+ * $Date: 2013/07/23 06:45:20 $
  **********************************************************/
 
 include_once("lib/dglibcommon");
@@ -61,7 +61,8 @@ function mod_passwd ($data)
     global $basedir;
 
     /* ʸΥå */
-    if (check_passwd($data["newpasswd"], MINADMINPASSWD, MAXADMINPASS) === FALSE) {
+    if (check_passwd($data["newpasswd"], (int)$web_conf["global"]["minpasswordlength"], 
+        (int)$web_conf["global"]["maxpasswordlength"]) === FALSE) {
         return FALSE;
     }
 
