@@ -24,10 +24,9 @@
  * ᡼󥰥ꥹԽ
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.2 $
- * $Date: 2010/06/10 05:23:52 $
+ * $Revision: 1.16 $
+ * $Date: 2012/09/26 06:54:13 $
  **********************************************************/
-
 include_once("../../initial");
 include_once("lib/dglibpostldapadmin");
 include_once("lib/dglibcommon");
@@ -36,79 +35,10 @@ include_once("lib/dglibldap");
 include_once("lib/dglibsess");
 
 /********************************************************
-ƥڡ
-*********************************************************/
-
-define("OPERATION", "᡼󥰥ꥹԽ");
-
-/***********************************************************
- * 饹: ˥塼
- **********************************************************/
-Class my_page extends page {
-
-    /***********************************************************
-     * ܥǥɽʥС饤ɡ
-     **********************************************************/
-    function display_body() {
-
-        global $result;
-        global $sesskey;
-        global $domain;
-        global $web_conf;
-        global $displayml;
-        global $url_data;
-
-        $newml = "";
-        if (isset($_POST["newml"])) {
-            $newml = htmlspecialchars($_POST["newml"]);
-        }
-
-        $domain = htmlspecialchars($domain);
-        print <<<EOD
-
-<script type="text/javascript">
-<!--
-function sysSubmit(url) {
-    document.ml.action = url;
-    document.ml.submit();
-}
-// -->
-</script>
-<form method="post" action="index.php" name="ml">
-<table>
-  <tr>
-    <td>
-        <select size="10" name="mladdr">
-
-EOD;
-
-        $displayml = $web_conf[$url_data["script"]]["displayml"];
-        usort($result, "ml_sort");
-        reset($result);
-        foreach($result as $i) {
-            $mldisp = $i["$displayml"][0];
-            $mldisp = htmlspecialchars($mldisp);
-            $mladdr = $i["mail"][0];
-            $mladdr = htmlspecialchars($mladdr);
-            print("          <option value=\"$mladdr\">$mldisp" . "\n");
-        }
-
-        print <<<EOD
-        </select>
-    </td>
-    <td valign="bottom">
-        <input type="submit" name="add" value="" class="ml_add_btn" onClick="return sysSubmit('mod.php')"><br><input type="submit" name="del" value="" class="ml_del_btn"onClick="return msgConfirm('򤷤᡼󥰥ꥹȥɥ쥹ޤ\\nǤ')">
-    </td>
-  </tr>
-</table>
-<br>
-<input type="text" size="40" maxlength="32" name="newml" value="$newml"><span class="maildomain">@$domain</span>
-<input type="submit" name="add" value="" class="new_add_btn">
-<input type="hidden" name="sk" value="$sesskey">
-</form>
-EOD;
-    }
-};
+ *ƥڡ
+ *********************************************************/
+define("OPERATION", "Modifying mailinglist");
+define("TMPLFILE", "admin_ml_mod.tmpl");
 
 /*********************************************************
  * add_ml
@@ -125,7 +55,9 @@ EOD;
 function add_ml($newml)
 {
     global $web_conf;
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
     global $domain;
     global $url_data;
 
@@ -135,10 +67,13 @@ function add_ml($newml)
     $ret = check_duplicate($mail);
     if ($ret == LDAP_FOUNDUSER || $ret == LDAP_FOUNDALIAS ||
         $ret == LDAP_FOUNDOTHER) {
-        $err_msg = "᡼륢ɥ쥹ϴ˻ȤƤޤ";
+        $err_msg = $msgarr['11001'][SCREEN_MSG];
+        $log_msg = $msgarr['11001'][LOG_MSG];
         return FALSE;
     } elseif ($ret == LDAP_ERRUSER) {
-        return FALSE;
+        result_log(OPERATION . ":NG:" . $log_msg);
+        syserr_display();
+        exit (1);
     }
 
     /* LDAPɲ° */
@@ -153,13 +88,19 @@ function add_ml($newml)
     /* LDAPȥɲ */
     $ret = LDAP_add_entry($add_dn, $attr);
     if ($ret != LDAP_OK) {
-        return FALSE;
+        result_log(OPERATION . ":NG:" . $log_msg);
+        syserr_display();
+        exit (1);
     }
 
     $dispml = $web_conf[$url_data["script"]]["displayml"];
-    $dispval = $attr["$dispml"];
+    $dispval = "";
+    if (isset($attr["$dispml"])) {
+        $dispval = $attr["$dispml"];
+    }
 
-    $err_msg = "᡼󥰥ꥹȡ" . $dispval ."פޤ";
+    $err_msg = sprintf($msgarr['11002'][SCREEN_MSG], $dispval);
+    $log_msg = sprintf($msgarr['11002'][LOG_MSG], $dispval);
     return TRUE;
 }
 
@@ -178,7 +119,9 @@ function add_ml($newml)
 function del_ml($mladdr)
 {
     global $web_conf;
+    global $msgarr;
     global $err_msg;
+    global $log_msg;
     global $url_data;
 
     $dispml = $web_conf[$url_data["script"]]["displayml"];
@@ -192,12 +135,15 @@ function del_ml($mladdr)
                           $web_conf[$url_data["script"]]["ldapscope"], $result);
     /* ˺Ƥ */
     if ($ret == LDAP_ERR_NODATA) {
-        $err_msg = "ꤵ줿᡼󥰥ꥹȥɥ쥹ϴ˺Ƥޤ";
+        $err_msg = $msgarr['11003'][SCREEN_MSG];
+        $log_msg = $msgarr['11003'][LOG_MSG];
         return TRUE;
     }
     /* LDAP˼ */
     if ($ret != LDAP_OK) {
-        return FALSE;
+        result_log(OPERATION . ":NG:" . $log_msg);
+        syserr_display();
+        exit (1);
     }
 
     $del_dn = $result[0]["dn"];
@@ -206,25 +152,82 @@ function del_ml($mladdr)
     /* LDAPȥ */
     $ret = LDAP_del_entry($del_dn);
     if ($ret != LDAP_OK && $ret != LDAP_ERR_NODATA) {
-        return FALSE;
+        result_log(OPERATION . ":NG:" . $log_msg);
+        syserr_display();
+        exit (1);
     }
 
-    $err_msg = "᡼󥰥ꥹȡ" . $dispval . "פޤ";
+    $err_msg = sprintf($msgarr['11004'][SCREEN_MSG], $dispval);
+    $log_msg = sprintf($msgarr['11004'][LOG_MSG], $dispval);
     return TRUE;
 }
 
+/*********************************************************
+ * mlmod_location
+ *
+ * ᡼륢ɥ쥹̤ؤ
+ *
+ * []
+ *        ʤ
+ *
+ * [֤]
+ *        ʤ
+ **********************************************************/
+function mlmod_location()
+{
+    global $sesskey;
+
+    /* å */
+    $hidden  = "<input type=\"hidden\" name=\"sk\" value=\"" .
+                $sesskey . "\">";
+    $hidden .= "<input type=\"hidden\" name=\"mladdr\" value=\"" .
+                $_POST["mladdr"] . "\">";
+
+    /* HTML */
+    display_header();
+    print <<<EOD
+<script type="text/javascript">
+<!--
+function msgConfirm(msg) {
+    return(window.confirm(msg));
+}
+
+function dgpSubmit(url) {
+    document.common.action = url;
+    document.common.submit();
+}
+// -->
+</script>
+<body onload="dgpSubmit('./mod.php')">
+...
+<form method="post" name="common">
+    $hidden
+</form>
+</body>
+</html>
+EOD;
+    exit;
+}
+
 /***********************************************************
  * 
  **********************************************************/
 
-/* 󥹥󥹺 */
-$pg = new my_page();
+/*  */
+$tag["<<TITLE>>"] = "";
+$tag["<<JAVASCRIPT>>"] = "";
+$tag["<<SK>>"] = "";
+$tag["<<TOPIC>>"] = "";
+$tag["<<MESSAGE>>"] = "";
+$tag["<<TAB>>"] = "";
+$tag["<<MLADDRS>>"] = "";
+$tag["<<NEWML>>"] = "";
+$tag["<<MLDOMAIN>>"] = "";
 
 /* ե롢ִեɹåå */
 $ret = init();
 if ($ret === FALSE) {
-    $sys_err = TRUE;
-    $pg->display(NULL);
+    syserr_display();
     exit (1);
 }
 
@@ -236,17 +239,19 @@ if (isset($_POST["add"])) {
 
     /* ɥ쥹ν񼰥å */
     if ($_POST["newml"] == "") {
-        $err_msg = "᡼󥰥ꥹȥɥ쥹ϤƤޤ";
-        result_log(OPERATION . ":NG:" . $err_msg);
+        $err_msg = $msgarr['11005'][SCREEN_MSG];
+        $log_msg = $msgarr['11005'][LOG_MSG];
+        result_log(OPERATION . ":NG:" . $log_msg);
     } else {
         if (check_name($_POST["newml"], MAXNAME) === FALSE) {
-            $err_msg = "᡼󥰥ꥹȥɥ쥹ηǤ";
-            result_log(OPERATION . ":NG:" . $err_msg);
+            $err_msg = $msgarr['11006'][SCREEN_MSG];
+            $log_msg = $msgarr['11006'][LOG_MSG];
+            result_log(OPERATION . ":NG:" . $log_msg);
         } else {
             if (add_ml($_POST["newml"]) === FALSE) {
-                result_log(OPERATION . ":NG:" . $err_msg);
+                result_log(OPERATION . ":NG:" . $log_msg);
             } else {
-                result_log(OPERATION . ":OK:" . $err_msg);
+                result_log(OPERATION . ":OK:" . $log_msg);
                 $_POST["newml"] = "";
             }
         }
@@ -257,17 +262,30 @@ if (isset($_POST["add"])) {
 
     if (isset($_POST["mladdr"])) {
         if (del_ml($_POST["mladdr"]) === FALSE) {
-            result_log(OPERATION . ":NG:" . $err_msg);
+            result_log(OPERATION . ":NG:" . $log_msg);
         } else {
-            result_log(OPERATION . ":OK:" . $err_msg);
+            result_log(OPERATION . ":OK:" . $log_msg);
             $err_msg = htmlspecialchars($err_msg);
         }
 
     } else {
-        $err_msg = "᡼󥰥ꥹȥɥ쥹򤵤Ƥޤ";
-        result_log(OPERATION . ":NG:" . $err_msg);
+        $err_msg = $msgarr['11007'][SCREEN_MSG];
+        $log_msg = $msgarr['11007'][LOG_MSG];
+        result_log(OPERATION . ":NG:" . $log_msg);
     }
 
+/* ᡼륢ɥ쥹ɲá */
+} else if (isset($_POST["ml_add"])) {
+
+    if (isset($_POST["mladdr"])) {
+        /* ᡼󥰥ꥹȤ򤵤Ƥ */
+        mlmod_location();
+    } else {
+        /* ᡼󥰥ꥹȤ򤵤Ƥʤ */
+        $err_msg = $msgarr['12001'][SCREEN_MSG];
+        $log_msg = $msgarr['12001'][LOG_MSG];
+        result_log(OPERATION . ":NG:" . $log_msg);
+    }
 }
 
 $err_tmp = $err_msg;
@@ -284,12 +302,12 @@ $ret = main_get_entry($dn, $filter, array(), $web_conf[$url_data["script"]]["lda
 
 /* LDAP˼ */
 if ($ret != LDAP_OK && $ret != LDAP_ERR_NODATA) {
-    result_log(OPERATION . ":NG:" . $err_msg);
+    result_log(OPERATION . ":NG:" . $log_msg);
     if ($err_tmp != "" && $err_tmp != $err_msg) {
         $err_msg = $err_tmp . "<BR>" . $err_msg;
     }
     $sys_err = TRUE;
-    $pg->display(NULL);
+    syserr_display();
     exit (1);
 }
 if ($ret == LDAP_ERR_NODATA) {
@@ -300,7 +318,41 @@ if ($ret == LDAP_ERR_NODATA) {
  * ɽ
  **********************************************************/
 
+/* ᡼󥰥ꥹȥɥ쥹ݻ */
+$newml = "";
+if (isset($_POST["newml"])) {
+    $newml = htmlspecialchars($_POST["newml"]);
+}
+
+/* ɽѤLDAP° */
+$displayml = $web_conf[$url_data["script"]]["displayml"];
+
+/* ᡼󥰥ꥹȤΥȥ򥽡 */
+usort($result, "ml_sort");
+reset($result);
+
+/* ᡼󥰥ꥹȤΥȥ򣱤ĤļɽѤ˲ù */
+$mladdrs = "";
+foreach($result as $i) {
+    $mldisp = $i["$displayml"][0];
+    $mldisp = htmlspecialchars($mldisp);
+    $mladdr = $i["mail"][0];
+    $mladdr = htmlspecialchars($mladdr);
+    $mladdrs .= "<option value=\"$mladdr\">$mldisp" . "\n";
+}
+
+/* ͤ򥻥å */
+set_tag_common($tag, "");
+$tag["<<MLADDRS>>"] = $mladdrs;
+$tag["<<NEWML>>"] = $newml;
+$tag["<<MLDOMAIN>>"] = htmlspecialchars($domain);
+
 /* ڡν */
-$pg->display(CONTENT);
+$ret = display(TMPLFILE, $tag, array(), "", "");
+if ($ret === FALSE) {
+    result_log($log_msg, LOG_ERR);
+    syserr_display();
+    exit(1);
+}
 
 ?>
