@@ -24,8 +24,8 @@
  * CSV̲
  *
  * $RCSfile: result.php,v $
- * $Revision: 1.11 $
- * $Date: 2014/01/24 02:48:59 $
+ * $Revision: 1.15 $
+ * $Date: 2014/05/01 00:49:36 $
  **********************************************************/
 
 include_once("../../initial");
@@ -34,6 +34,8 @@ include_once("lib/dglibcommon");
 include_once("lib/dglibpage");
 include_once("lib/dglibsess");
 include_once("lib/dglibldap");
+include_once("lib/dglibforward");
+include_once("lib/dglibdovecot");
 
 /********************************************************
 ƥڡ
@@ -47,6 +49,7 @@ define("CSV_BATCH_NG_END", 2);         # ()
 
 /* CSVκ */
 define("CSV_ADDCOLUMN_MAX", 6);
+define("CSV_ADDCOLUMN_FORWARD_MAX", 8);
 
 /* ʸΥ󥳡ǥ */
 define("USERNAME_DISP_ENCODING", "EUC-JP");
@@ -66,6 +69,8 @@ define("READ_CSVFILE_ENCODING",  "SJIS");
  *        $csvdata[3] = (᡼륨ꥢ)
  *        $csvdata[4] = (žɥ쥹)
  *        $csvdata[5] = (Ф˥᡼Ĥ/Ĥʤ)
+ *        $csvdata[6] = (mailFilterOrderForwardConfONλΤ)
+ *        $csvdata[7] = (mailFilterArticleForwardConfONλΤ)
  * [֤]
  *        Ѵ줿
  *        $userdata["uid"] = (桼̾)
@@ -75,16 +80,21 @@ define("READ_CSVFILE_ENCODING",  "SJIS");
  *        $userdata["alias"] = (᡼륨ꥢ)
  *        $userdata["transes"][0] = (᡼žɥ쥹)
  *        $userdata["save"] = (Ф˥᡼Ĥ/Ĥʤ)
+ *        $userdata["order"] = (mailFilterOrderForwardConfONλΤ)
+ *        $userdata["article"] = (mailFilterArticleForwardConfONλΤ)
  *
  **********************************************************/
 function mk_ldap_array($csvdata)
 {
+    global $web_conf;
+    global $url_data;
+
     /* ηѴ */
 
     # 桼̾ʷɽѤEUCѴ
     if (isset($csvdata[0])) {
-        $userdata["uid"] = mb_convert_encoding($csvdata[0], USERNAME_DISP_ENCODING,
-                                           READ_CSVFILE_ENCODING);
+        $userdata["uid"] = mb_convert_encoding($csvdata[0], 
+                                USERNAME_DISP_ENCODING, READ_CSVFILE_ENCODING);
     }
 
     if (isset($csvdata[1])) {
@@ -115,6 +125,19 @@ function mk_ldap_array($csvdata)
         $userdata["save"] = $csvdata[5];
     }
 
+    // forwardconfonξϥȥƥ
+    if ($web_conf[$url_data['script']]['forwardconf'] === FORWARD_ON) {
+        // ¸ߤгǼ
+        if (isset($csvdata[6])) {
+            $userdata["order"] = $csvdata[6];
+        }
+
+        // ƥ뤬¸ߤгǼ
+        if (isset($csvdata[7])) {
+            $userdata["article"] = $csvdata[7];
+        }
+    }
+
     return $userdata;
 
 }
@@ -222,10 +245,11 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
     global $domain;
     global $userdn;
     global $url_data;
+    global $ldapdata;
 
     $type = ADD_MODE;
 
-    /* CSVեηå */
+    // CSVեηå
     if (check_userdata($userdata) === FALSE) {
         printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
         ob_flush();
@@ -384,6 +408,30 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
             }
             $err_msg = $msgarr['14005'][SCREEN_MSG];
             $log_msg = $msgarr['14005'][LOG_MSG];
+
+            // forwardconfonξsieveեκ
+            if ($web_conf[$url_data['script']]['forwardconf'] === FORWARD_ON) {
+                $ldapdata[0]['mailFilterArticle'] = explode(":", $userdata['article']);
+                $ldapdata[0]['mailFilterOrder'][0] = $userdata['order'];
+                $ldapdata[0]['mailDirectory'][0] = $web_conf[$url_data["script"]]["basemaildir"] . "/" . $userdata['uid'] . "/";
+
+                // sieveե
+                $ret = make_sievefile();
+                // sieveեκ˼Ԥϲ̺ɽ
+                if ($ret === FALSE) {
+                    $err_msg = $msgarr['26011'][SCREEN_MSG];
+                    printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"])                           , $err_msg);
+                    ob_flush();
+                    flush();
+                    result_log($logstr . ":NG:" .  $userdata["uid"] .
+                               ":$log_msg(line ${line})");
+                    if (isset($_POST["err"])) {
+                        return CSV_BATCH_NG_ERR_IGNORE;
+                    } else {
+                        return CSV_BATCH_NG_END;
+                    }
+                }
+            }
         /* եå */
         } else {
             $err_msg = $msgarr['14014'][SCREEN_MSG];
@@ -413,6 +461,25 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
             }
             $err_msg = $msgarr['14006'][SCREEN_MSG];
             $log_msg = $msgarr['14006'][LOG_MSG];
+
+            // forwardconfonξsieveեκ
+            if ($web_conf[$url_data['script']]['forwardconf'] === FORWARD_ON) {
+                $ldapdata[0]['mailFilterArticle'] = explode(":", $userdata['article']);
+                $ldapdata[0]['mailFilterOrder'][0] = $userdata['order'];
+                $ldapdata[0]['mailDirectory'][0] = $web_conf[$url_data["script"]]["basemaildir"] . "/" . $userdata['uid'] . "/";
+
+                // sieveե
+                $ret = make_sievefile();
+                // sieveեκ˼Ԥϲ̺ɽ
+                if ($ret === FALSE) {
+                    $err_msg = $msgarr['26011'][SCREEN_MSG];
+                    if (isset($_POST["err"])) {
+                        return CSV_BATCH_NG_ERR_IGNORE;
+                    } else {
+                        return CSV_BATCH_NG_END;
+                    }
+                }
+            }
         /* եå */
         } else {
             $err_msg = $msgarr['14015'][SCREEN_MSG];
@@ -601,6 +668,9 @@ function read_csvfile($fp, $logstr)
     global $msgarr;
     global $err_msg;
     global $log_msg;
+    global $web_conf;
+    global $url_data;
+
     $line = 0;
     $fchecknum = 0;
     $fcheckuser = array();
@@ -625,9 +695,15 @@ function read_csvfile($fp, $logstr)
         /* ԿΥ */
         $line++;
 
+        $colum_num = CSV_ADDCOLUMN_MAX;
+        // 
+        if ($web_conf[$url_data['script']]['forwardconf'] === FORWARD_ON) {
+            $colum_num = CSV_ADDCOLUMN_FORWARD_MAX;
+        }
+
         /* Υå */
         if ($_POST["runtype"] == "add") {
-            $ret = csv_column_check($csvdata, CSV_ADDCOLUMN_MAX, $line,
+            $ret = csv_column_check($csvdata, $colum_num, $line,
                                     $logstr);
             if ($ret === CSV_BATCH_NG_END) {
                 break;
@@ -636,11 +712,11 @@ function read_csvfile($fp, $logstr)
             }
         }
 
-        /* LDAPϿѴ */
+        // LDAPϿѴ
         $userdata = mk_ldap_array($csvdata);
 
         if ($_POST["runtype"] == "add") {
-            /* ȰϿ */
+            // ȰϿʷåԤäƤ
             $ret = csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line);
             if ($ret === CSV_BATCH_NG_END) {
                 break;
