@@ -24,8 +24,8 @@
  * ѥ桼˥塼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.3 $
- * $Date: 2010/06/23 00:21:05 $
+ * $Revision: 1.9 $
+ * $Date: 2012/09/19 00:02:52 $
  **********************************************************/
 
 include_once("../initial");
@@ -35,25 +35,45 @@ include_once("lib/dglibcommon");
 include_once("lib/dglibpage");
 include_once("lib/dglibsess");
 
+/********************************************************
+ * ƥڡ
+ ********************************************************/
+
+define("TMPLFILE",  "admin_user_menu.tmpl");
+
 /***********************************************************
  * 
  **********************************************************/
-/* 󥹥󥹺 */
-$pg  = new page();
+
+/*  */
+$tag["<<TITLE>>"]      = "";
+$tag["<<JAVASCRIPT>>"] = "";
+$tag["<<SK>>"]         = "";
+$tag["<<TOPIC>>"]      = "";
+$tag["<<MESSAGE>>"]    = "";
+$tag["<<TAB>>"]        = "";
+$tag["<<MENU>>"]       = "";
 
 /* ե䥿ִեɹåΥå */
 $ret = init();
 if ($ret === FALSE) {
-    $sys_err = TRUE;
-    $pg->display(NULL);
-    exit (1);
+    syserr_display();
+    exit(1);
 }
 
 /***********************************************************
  * ɽ
  **********************************************************/
 
-/* ڡν */
-$pg->display(MENU);
+/*   */
+set_tag_common($tag);
+$tag["<<MENU>>"] = get_menu();
 
+/* ڡν */
+$ret = display(TMPLFILE, $tag, array(), "", "");
+if ($ret === FALSE) {
+    result_log($log_msg, LOG_ERR);
+    syserr_display();
+    exit(1);
+}
 ?>
