@@ -24,8 +24,8 @@
  * ѥ桼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.17 $
- * $Date: 2013/09/05 06:08:59 $
+ * $Revision: 1.19 $
+ * $Date: 2014/04/24 05:03:43 $
  **********************************************************/
 
 include_once("../../initial");
@@ -45,6 +45,8 @@ define("OPERATION",  "Searching user account");
 
 define("STATUS_INPUT",  0);
 define("STATUS_SEARCH", 1);
+
+define("FORWARD_ON", "1");
 /*********************************************************
  * set_tag_data
  *
@@ -276,6 +278,14 @@ function set_loop_tag($ldap_result, $filter, $page, $form_name_encode, &$looptag
 
 EOD;
 
+        // forwardconfonξž󥯤
+        if ($web_conf[$url_data["script"]]["forwardconf"] === FORWARD_ON) {
+            $looptag[$k]["<<FORWARD>>"] = <<<EOD
+<a href="#" onClick="allSubmit('forward.php', '$page', '$userdn', '$form_name_encode')">ž</a>
+
+EOD;
+        }
+
         /* ץ饰Խ̤ؤΥɽ */
         $count = count($plugindata);
         if ($count > 0) {
@@ -320,6 +330,8 @@ function csv_output()
     global $dispusr;
     global $ldap_result;
     global $domain;
+    global $web_conf;
+    global $url_data;
 
     /* ̤ɽ°̾ǥ */
     usort($ldap_result, "user_sort");
@@ -374,6 +386,24 @@ function csv_output()
             array_push($csvdata, "");
         }
 
+        // forwardconfonξϥȥƥǼ
+        if ($web_conf[$url_data['script']]['forwardconf'] === FORWARD_ON) {
+            // 
+            if (isset($userdata["mailFilterOrder"])) {
+                array_push($csvdata, $userdata["mailFilterOrder"][0]);
+            } else {
+                array_push($csvdata, "");
+            }
+
+            // ƥ
+            if (isset($userdata["mailFilterArticle"])) {
+                $article = implode(":", $userdata["mailFilterArticle"]);
+                array_push($csvdata, $article);
+            } else {
+                array_push($csvdata, "");
+            }
+        }
+
         $csvline = mk_csv_line($csvdata);
         print("$csvline\r\n");
     }
@@ -449,6 +479,8 @@ $tag["<<TRANS>>"] = "";
 $tag["<<SAVEON>>"] = "";
 $tag["<<SAVEOFF>>"] = "";
 $tag["<<HIDDEN>>"] = "";
+$tag["<<FORWARD_START>>"] = "<!--";
+$tag["<<FORWARD_END>>"] = "-->";
 
 $looptag = array();
 
@@ -583,6 +615,11 @@ if (isset($_POST['form_name'])) {
 /***********************************************************
  * ɽ
  **********************************************************/
+// žꥫɽ
+if ($web_conf[$url_data['script']]['forwardconf'] === FORWARD_ON) {
+    $tag["<<FORWARD_START>>"] = "";
+    $tag["<<FORWARD_END>>"] = "";
+}
 /* ڡν */
 if (isset($_POST['csvdownload']) && count($ldap_result) > 0) {
     $err_msg = $msgarr['15006'][SCREEN_MSG];
