@@ -24,8 +24,8 @@
  * ѥ桼
  *
  * $RCSfile: mod.php,v $
- * $Revision: 1.12 $
- * $Date: 2012/09/26 06:33:03 $
+ * $Revision: 1.13 $
+ * $Date: 2014/04/23 02:36:08 $
  **********************************************************/
 
 include_once("../../initial");
@@ -45,6 +45,7 @@ define("OPERATION", "Searching user account");
 
 define("MODE_LDAPDATA", 0);
 define("MODE_POSTDATA", 1);
+define("FORWARD_ON", "1");
 
 /*********************************************************
  * set_tag_data
@@ -131,6 +132,8 @@ $tag["<<ALIAS>>"] = "";
 $tag["<<TRANS>>"] = "";
 $tag["<<SAVEON>>"] = "";
 $tag["<<SAVEOFF>>"] = "";
+$tag["<<FORWARD_START>>"] = "";
+$tag["<<FORWARD_END>>"] = "";
 
 /* 桼Ǽ */
 if (isset($_POST["dn"])) {
@@ -319,6 +322,13 @@ set_tag_common($tag, $javascript);
 /* å */
 set_tag_data($_POST, $tag);
 
+// ForwardConfONξϵɽä
+if ($web_conf[$url_data['script']]['forwardconf'] === FORWARD_ON) {
+    $tag["<<FORWARD_START>>"] = "<!--";
+    $tag["<<FORWARD_END>>"] = "-->";
+}
+
+// ڡν
 $ret = display(TMPLFILE, $tag, array(), "", "");
 if ($ret === FALSE) {
     result_log($log_msg, LOG_ERR);
